@@ -8,20 +8,25 @@ class Command:
     def __init__(self, endpoint):
         self.endpoint = endpoint
 
-    def run_command(self, org_slug, target_id, action, metadata, payload, ttl_sec):
+    def run_command(self, context_data, org_slug, target_id, action, metadata, payload, ttl_sec):
         if org_slug is None:
             raise Exception('Param org_slug is missing')
         if target_id is None:
             raise Exception('Param target_id is missing')
         if action is None:
             raise Exception('Param action is missing')
-        if metadata is None:
-            raise Exception('Param metadata is missing')
         if payload is None:
             raise Exception('Param payload is missing')
         if ttl_sec < 300 or ttl_sec > 900:
             raise Exception('Param ttl_sec must be between 300 and 900 seconds')
 
+        if metadata is None:
+            metadata = {}
+
+        metadata["workflowId"] = context_data.get("workflowId")
+        metadata["pipelineId"] = context_data.get("pipelineId")
+        metadata["taskId"] = context_data.get("taskId")
+
         url = self.endpoint + "/internal"
         date_now = datetime.now(timezone.utc) + timedelta(0, ttl_sec)
 
